Storage

Struct Storage 

#[repr(C)]
pub struct Storage<T, D> { value: UnsafeCell<MaybeUninit<T>>, state: Cell<State<D>>, }
🔬This is a nightly-only experimental API. (thread_local_internals)

Fields

value: UnsafeCell<MaybeUninit<T>>
🔬This is a nightly-only experimental API. (thread_local_internals)
state: Cell<State<D>>
🔬This is a nightly-only experimental API. (thread_local_internals)

Implementations

Source

impl<T, D> Storage<T, D>
where D: DestroyedState,

pub const fn new() -> Storage<T, D>

🔬This is a nightly-only experimental API. (thread_local_internals)
pub unsafe fn get_or_init( &self, i: Option<&mut Option<T>>, f: impl FnOnce() -> T, ) -> *const T

🔬This is a nightly-only experimental API. (thread_local_internals)

Gets a pointer to the TLS value, potentially initializing it with the provided parameters. If the TLS variable has been destroyed, a null pointer is returned.

The resulting pointer may not be used after reentrant inialialization or thread destruction has occurred.

Safety

The self reference must remain valid until the TLS destructor is run.

unsafe fn get_or_init_slow( &self, i: Option<&mut Option<T>>, f: impl FnOnce() -> T, ) -> *const T

🔬This is a nightly-only experimental API. (thread_local_internals)
Safety

The self reference must remain valid until the TLS destructor is run.